@@ -1,6 +1,6 @@
 use csml_engine::{
     data::{BotOpt, CsmlRequest},
-    start_conversation, delete_expired_data,
+    delete_expired_data, start_conversation,
 };
 use csml_interpreter::{
     data::{csml_bot::CsmlBot, csml_flow::CsmlFlow, Client},
@@ -34,6 +34,8 @@ fn init_request(string: &str) -> CsmlRequest {
             "content": { "text": string},
         }),
         metadata: json!({"some": "custom-value"}),
+        ttl_duration: None,
+        low_data_mode: None,
     }
 }
 
@@ -62,6 +64,7 @@ fn init_bot() -> CsmlBot {
         bot_ast: None,
         no_interruption_delay: None,
         env: None,
+        modules: None,
     }
 }
 
