@@ -3,7 +3,7 @@ use crate::{
     encrypt::{decrypt_data, encrypt_data},
     Client, Context,
 };
-use csml_interpreter::data::{CsmlBot, CsmlFlow, Message};
+use csml_interpreter::data::{CsmlBot, CsmlFlow, Message, Module};
 use serde::{Deserialize, Serialize};
 use serde_json::Value;
 
@@ -121,6 +121,7 @@ pub struct SerializeCsmlBot {
     pub default_flow: String,
     pub no_interruption_delay: Option<i32>,
     pub env: Option<String>,
+    pub modules: Option<Vec<Module>>,
 }
 
 /**
@@ -151,6 +152,7 @@ impl CsmlBotBincode {
             default_flow: self.default_flow,
             no_interruption_delay: None,
             env: None,
+            modules: None,
         }
     }
 }
@@ -178,6 +180,7 @@ pub fn to_serializable_bot(bot: &CsmlBot) -> SerializeCsmlBot {
             Some(value) => encrypt_data(value).ok(),
             None => None,
         },
+        modules: bot.modules.to_owned(),
     }
 }
 
@@ -213,6 +216,7 @@ impl SerializeCsmlBot {
                 Some(value) => decrypt_data(value).ok(),
                 None => None,
             },
+            modules: self.modules.to_owned(),
         }
     }
 }
@@ -273,7 +277,7 @@ pub fn to_dynamo_bot(csml_bot: &CsmlBot) -> DynamoBot {
 }
 
 impl DynamoBot {
-    pub fn to_bot(&self, flows: Vec<CsmlFlow>) -> CsmlBot {
+    pub fn to_bot(&self, flows: Vec<CsmlFlow>, modules: Vec<Module>) -> CsmlBot {
         CsmlBot {
             id: self.id.to_owned(),
             name: self.name.to_owned(),
@@ -296,6 +300,7 @@ impl DynamoBot {
                 Some(value) => decrypt_data(value).ok(),
                 None => None,
             },
+            modules: Some(modules),
         }
     }
 }
@@ -307,6 +312,8 @@ pub struct CsmlRequest {
     pub callback_url: Option<String>,
     pub payload: serde_json::Value,
     pub metadata: serde_json::Value,
+    pub ttl_duration: Option<serde_json::Value>,
+    pub low_data_mode: Option<serde_json::Value>,
 }
 
 pub enum Database {
@@ -316,9 +323,22 @@ pub enum Database {
     Dynamodb(DynamoDbClient),
     #[cfg(feature = "postgresql")]
     Postgresql(PostgresqlClient),
+    #[cfg(feature = "sqlite")]
+    SqLite(SqliteClient),
     None,
 }
 
+#[cfg(feature = "sqlite")]
+pub struct SqliteClient {
+    pub client: diesel::prelude::SqliteConnection,
+}
+
+#[cfg(feature = "sqlite")]
+impl SqliteClient {
+    pub fn new(client: diesel::prelude::SqliteConnection) -> Self {
+        Self { client }
+    }
+}
 
 #[cfg(feature = "postgresql")]
 pub struct PostgresqlClient {
@@ -415,10 +435,10 @@ pub enum EngineError {
     #[cfg(any(feature = "dynamo"))]
     S3ErrorCode(u16),
 
-    #[cfg(any(feature = "postgresql"))]
-    PsqlErrorCode(String),
-    #[cfg(any(feature = "postgresql"))]
-    PsqlMigrationsError(String),
+    #[cfg(any(feature = "postgresql", feature = "sqlite"))]
+    SqlErrorCode(String),
+    #[cfg(any(feature = "postgresql", feature = "sqlite"))]
+    SqlMigrationsError(String),
 }
 
 impl From<serde_json::Error> for EngineError {
@@ -492,16 +512,16 @@ impl From<serde_dynamodb::Error> for EngineError {
     }
 }
 
-#[cfg(any(feature = "postgresql"))]
+#[cfg(any(feature = "postgresql", feature = "sqlite"))]
 impl From<diesel::result::Error> for EngineError {
     fn from(e: diesel::result::Error) -> Self {
-        EngineError::PsqlErrorCode(e.to_string())
+        EngineError::SqlErrorCode(e.to_string())
     }
 }
 
-#[cfg(any(feature = "postgresql"))]
+#[cfg(any(feature = "postgresql", feature = "sqlite"))]
 impl From<diesel_migrations::RunMigrationsError> for EngineError {
     fn from(e: diesel_migrations::RunMigrationsError) -> Self {
-        EngineError::PsqlMigrationsError(e.to_string())
+        EngineError::SqlMigrationsError(e.to_string())
     }
 }
